#!/usr/bin/python3

import json
import argparse
import requests

parser = argparse.ArgumentParser(description='Create a JIRA issue from Svacer hook')

parser.add_argument('jira_address', help='JIRA server address')

# project code can be found on the project main page below the project lead
parser.add_argument('project_code', help='Project code where the issue should be created')

# token can be created as described here:
# https://confluence.atlassian.com/enterprise/using-personal-access-tokens-1026032365.html
parser.add_argument('token', help='The token for authentication')

# issue types from one of the configured for the project:
# https://<jira-url>/secure/ShowConstantsHelp.jspa?decorator=popup#IssueTypes
parser.add_argument('issue_name', help='Issue type name for the created issue')

# svacer hook arguments
parser.add_argument('url', help='The URL with the issue')
parser.add_argument('marker', help='Path to file with marker details')

args = parser.parse_args()

# open JSON file with marker data
with open(args.marker) as marker_file:
  data = json.load(marker_file)

  # svace warning type, e.g. DEREF_OF_NULL
  issue_type = data['warnClass']

  # generate location as file:line from full path
  issue_location = data['file'].rsplit('/', 1)[-1] + ':' + str(data['line'])

  # svace warning message
  issue_message = data['msg']

  # use API version 2 as stable
  url = args.jira_address + "/rest/api/2/issue/"

  headers = {
    "Content-Type": "application/json",
    "Authorization": "Bearer " + args.token
  }

  payload = {
    "fields": {
      "summary": "[SVACE] " + issue_type + " at " + issue_location,
      "description": "Message: " + issue_message + "\n\n" + "Link: " + args.url,
      "labels": [
        data['checker_severity']
      ],
      "project": {
        "key": args.project_code
      },
      "issuetype": {
        "name": args.issue_name
      },
    }
  }

  response = requests.post(url, json=payload, headers=headers)
  # uncomment to debug the problems with response
  # print(response.content)
